
package dataspork.util;
import java.util.TreeSet;
import java.util.Comparator;
import java.util.Iterator;

public class KVectors  {
   protected double kv[];
   protected double kmag[];
   public KVectors(double[] boxsize,int nshells){
      ComputeKV(boxsize,nshells);
   }

   public void ComputeKV(double[] boxsize,int nshells){
     int dim = boxsize.length;

     double fac[] = new double[dim];
    
     for (int d=0; d<dim; d++){
        fac[d] = 2*Math.PI/boxsize[d];
     }

// Triple compares vectors  by their magnitudes
     Triple c = new Triple(0,0,0);

// A Set will store elements with no duplication
// A TreeSet will store them in sorted order
     TreeSet kvset = new TreeSet(c);

     kv = new double[dim*nshells];
     kmag = new double[nshells];
     
     
     if (dim==3) {
        for (int i=1; i<nshells+1; i++){
           for (int j=0; j<nshells+1; j++){
              for (int k=0; k<nshells+1; k++){
                if ((i*i+j*j+k*k)<nshells*nshells){
                  kvset.add(new Triple(i,j,k));
                }
              }
           }
        }

        Iterator it = kvset.iterator();
        
//        System.out.println("fac:"+fac[0]+"  "+fac[1]+"  "+fac[2]+"\n");
        double mag;
        for (int i=0;i<nshells;i++){
          c =(Triple)it.next();    
          kv[i*dim] = c.i *fac[0];
          kv[i*dim+1] = c.j *fac[1];
          kv[i*dim+2] = c.k *fac[2];
          mag = 0.0;
          for (int d=0; d<dim;d++){
             mag += kv[i*dim+d]*kv[i*dim+d];
          }
          kmag[i] = Math.sqrt(mag);
 //         System.out.println(i+": "+c.i+" "+c.j+" "+c.k+" "+kmag[i]+"\n");
        }

     } else {
// Compute k vectors along k_x direction.
        for (int i=1; i<nshells+1; i++){
           kv[(i-1)*dim] = i*fac[0];
           kmag[i-1] = kv[(i-1)*dim];
           for (int d=1; d<dim; d++){
              kv[(i-1)*dim + d] = 0.0;
           }
        }
     }
  
   
   
   }

   public double[] getKVectors(){
      return kv;
   }

   public double[] getKMagnitude(){
      return kmag;
   }

     public class Triple implements Comparator {
        int i,j,k;
        int mag;
        public Triple(int i,int j,int k) {
            this.i = i;   
            this.j = j;   
            this.k = k;   
            mag = i*i + j*j + k*k;
        }
        public int compare(Object o1, Object o2){
           int ret=0; 
           if (((Triple)o1).mag > ((Triple)o2).mag) ret = 1;
           if (((Triple)o1).mag < ((Triple)o2).mag) ret = -1;
           return ret;
        }
        public boolean equals(Object ob){
          return (mag == ((Triple)ob).mag);
        }
        
     }

}
