package pupi.reader.restart;
import ncsa.hdf.hdflib.*;

public class HDFParser{
  
  protected HDFLibrary hdf;

  protected HDFDocHandler handler;

  protected String filename;

  protected int fileID;

  public HDFParser(HDFLibrary hdf) {
    this.hdf = hdf;
  }

  public void parse(String filename) {
    this.filename = filename;
    if (handler==null) return;
    try {
      fileID = hdf.Hopen(filename);
      boolean temp = hdf.Vstart(fileID);
      int ref = hdf.Vgetid(fileID,-1);
      Element e = new Element(ref,-1);
      handler.startDocument();
      handler.startElement(e);
      parseElements(ref);
      handler.endElement(e);
      handler.endDocument();
      hdf.Vend(fileID);
      hdf.Hclose(fileID);
    }
    catch (Throwable t) {t.printStackTrace();}
  }

  protected void parseElements(int ref) {
    try {
      int readID=hdf.Vattach(fileID,ref,"r");
      int ntags=hdf.Vntagrefs(readID);
      if (ntags>0) {
        int[] refs = new int[ntags];
        int[] tags = new int[ntags];
        hdf.Vgettagrefs(readID,tags,refs,ntags);
        for (int i=0; i<ntags; ++i) {
          Element e = new Element(refs[i],tags[i]);
          handler.startElement(e);
          //Recurse into tree if element is a group.
          if (hdf.Visvg(readID,refs[i])) parseElements(refs[i]);
          handler.endElement(e);
        }
      }
      hdf.Vdetach(readID);
    }
    catch (Throwable t) {t.printStackTrace();}
  }

  public void setDocumentHandler(HDFDocHandler h) {
    handler = h;
  }

  public class Element{

    public Element(int ref, int tag) {
      this.ref=ref;
      this.tag=tag;
      userTag=UpiTags.getUser(tag); 
      userTag=(this.userTag>=UpiTags.names.length)?-1:this.userTag;
    }

    public int ref;
    public int tag;
    public int userTag;

    public String toString() {
      if (userTag==UpiTags.UPI_GROUP) {
        return "group";
      }
      else {
        return UpiTags.names[userTag];
      }
    }

    public String getFilename() {
      return filename;
    }

    public HDFLibrary getHDFLibrary() {
      return hdf;
    }

    public boolean isVec() {
      return UpiTags.isVec(tag);
    }

    protected byte[] readRawData() {
      byte[] data=null;
      try {
        int length=hdf.Hlength(fileID,tag,ref);
        data = new byte[length];
        hdf.Hgetelement(fileID,tag,ref,data);
      }
      catch (Throwable t) {t.printStackTrace();}
      return data;
    }

    protected String readString() {
      String string=null;
      try {
        byte[] data=readRawData();
        int i=0;
        for (; i<data.length && data[i]!=32; i++){} //end at first space
        string = new String(data,0,i,"UTF8");
      }
      catch (Throwable t) {t.printStackTrace();}
      return string;
    }

    protected int readInteger() {
      byte[] temp = readRawData();
      return HDFNativeData.byteToInt(temp,0);
    }

    protected int[] readIntegerArray() {
      byte[] temp = readRawData();
      return HDFNativeData.byteToInt(4,temp.length/4-1,temp);
    }

    protected double[] readDoubleArray() {
      byte[] temp = readRawData();
      System.out.println("array size="+temp.length);
      byte[] temp2 = new byte[temp.length-4];
      for (int i=0; i<temp2.length; i++) temp2[i]=temp[i+4];
      return HDFNativeData.byteToDouble(0,temp.length/8,temp2);
    }
  }

}
